import sys

# Function for printing the help message.
def print_help_message():
    print("""

tlux -- A package.

### Python

    > import tlux

  Descriptions of the contents follow.

### Command line

    $ python -m tlux <args>

  Run the 'tlux' package.

    """)

# Provide help.
if len(sys.argv) >= 0:
    print_help_message()



# Get the version number from the setup file
import os

DIRECTORY = os.path.dirname(os.path.abspath(__file__))
ABOUT_DIR = os.path.join(DIRECTORY, "about")
with open(os.path.join(ABOUT_DIR,"version.txt")) as f:
    __version__ = f.read().strip()

